@@ -3,7 +3,7 @@ package HTTP::Message;
 use strict;
 use warnings;
 
-our $VERSION = '6.39';
+our $VERSION = '6.40';
 
 require HTTP::Headers;
 require Carp;
@@ -820,7 +820,7 @@ HTTP::Message - HTTP style message (base class)
 
 =head1 VERSION
 
-version 6.39
+version 6.40
 
 =head1 SYNOPSIS
 
@@ -940,12 +940,12 @@ The following options can be specified.
 
 =item C<charset>
 
-This override the charset parameter for text content.  The value
+This overrides the charset parameter for text content.  The value
 C<none> can used to suppress decoding of the charset.
 
 =item C<default_charset>
 
-This override the default charset guessed by content_charset() or
+This overrides the default charset guessed by content_charset() or
 if that fails "ISO-8859-1".
 
 =item C<alt_charset>
